
#include "mysqlcppapi/query/Query.h"
#include "mysqlcppapi/Connection.h"

namespace mysqlcppapi
{

Query::Query(const Connection& connection) 
: std::ios(), SQLQuery(), m_sharedptr_connection(new Connection(connection))
{
  //Connection will be deleted after the last unreference().
  Success = true;
}

Query::Query(const Query& src)
: std::ios(), SQLQuery(src), m_sharedptr_connection(src.m_sharedptr_connection)
// N.B. it's safe to default construct std::ios() here because the SQLQuery's
// std::stringstream base class will call std::ios::init().
{
}

Query::~Query()
{
}

Query& Query::operator=(const Query& src)
{
  m_sharedptr_connection = src.m_sharedptr_connection;
  SQLQuery::operator=(src);
  return *this;
}

bool Query::success()
{
  return Success ? m_sharedptr_connection->success() : false;
}

Result_NoData Query::execute()
{
  return m_sharedptr_connection->execute(str());
}

Result_NoData Query::execute(const std::string& strQuery)
{
  return m_sharedptr_connection->execute(strQuery);
}


Result_Use Query::use()
{
  return use(str());
}

Result_Use Query::use(const std::string& str)
{
  return m_sharedptr_connection->use(str);
}

Result_Store Query::store()
{
  return store(str());
}
 
Result_Store Query::store(const std::string& str)
{
  return m_sharedptr_connection->store(str);
}


int Query::affected_rows() const
{
  return m_sharedptr_connection->affected_rows();
}

int Query::insert_id ()
{
  return m_sharedptr_connection->insert_id();
}

std::string Query::error ()
{
  if (errmsg.size())
     return std::string(errmsg);
     
  return m_sharedptr_connection->error();
}

std::string Query::preview()
{
  return str();
}

  
} //namespace




