
#include "mysqlcppapi/query_results/Result_NoData.h"
#include "mysqlcppapi/Connection.h"

namespace mysqlcppapi
{

Result_NoData::Result_NoData()
{
  m_bSucceeded = false;
  m_InsertID = 0;
  m_RowsAffected = 0;
}

Result_NoData::Result_NoData(const Result_NoData& src)
{
  operator=(src);
}

Result_NoData::Result_NoData(const Connection& connection) 
{
  //It would be nice to just copy the Connection, instead of using a SharedPtr<>(new Connection),
  //but that would cause a circular #include.
  m_sharedptr_connection = type_sharedptr_connection(new Connection(connection));
  
  m_bSucceeded = false;
  m_InsertID = 0;
  m_RowsAffected = 0;

  if(m_sharedptr_connection)
  {
    m_bSucceeded = m_sharedptr_connection->success();
    m_InsertID = m_sharedptr_connection->insert_id();
    m_RowsAffected = m_sharedptr_connection->affected_rows();
    m_strInfo = m_sharedptr_connection->info();
  }
}

Result_NoData::~Result_NoData()
{
}

Result_NoData& Result_NoData::operator=(const Result_NoData& src)
{
  m_bSucceeded = src.m_bSucceeded;
  m_InsertID = src.m_InsertID;
  m_RowsAffected = src.m_RowsAffected;
  m_strInfo = src.m_strInfo;

  return *this;
}

bool Result_NoData::get_succeeded() const
{
  return m_bSucceeded;
}

int Result_NoData::get_insert_id() const
{
  return m_InsertID;
}

int Result_NoData::get_rows_affected() const
{
  return m_RowsAffected;
}

std::string Result_NoData::get_info() const
{
  return m_strInfo;
}


} //namespace



